import QtQuick 1.0
// import com.nokia.meego 1.0

Item {
    property string inReplyTo: "";
    property alias tweetText: postInput.text;
    id: tweetBox
    x: screen.width > 480 ? -601 : -381
    // y: 15
    z: 5
    Behavior on x {
        SpringAnimation { mass: 0.8; spring: 8; damping: 0.3 }
    }
    Rectangle {
        opacity: 0
        clip: true
        id: inputArea
        width: screen.width > 480 ? 600 : 380
        height: buttonflow.y + buttonflow.height + 5
        //color: "grey"
        smooth: true
        // border.width: 1
        // border.color: "#cbcbcb"
        radius: 5
        gradient: Gradient {
            GradientStop { position: 0.0; color: "#666" }
            GradientStop { position: 1.0; color: "#eee" }
        }
        Behavior on opacity {
            NumberAnimation { duration: 500; }
        }
        Rectangle {
            x: 0; y: 0; z:1
            width: screen.width > 480 ? 599 : 379
            height: bottomSpacer.y + bottomSpacer.height - 1
            color: "transparent"
            border.width: 1
            border.color: "grey"

            radius: 5
        }
        Image { // moving background
            z: 0
            id: bgimage
            source: "images/leaves_mix_1.png"
            x: -140
            y: 140
            smooth: true
            Behavior on x {
                NumberAnimation { duration: 20000; }
            }
            Behavior on y {
                NumberAnimation { duration: 20000; }
            }
        }
        Text {
            id: label
            text: (140 - postInput.text.length) + " characters left"
            font.pointSize: 12
            x: 25
            y: 5
        }

        Rectangle {
            id: postInputContainer
            width: screen.width > 480 ? 558 : 338
            height: screen.width > 480 ? 90 : 120
            color: "white"
            border.width: 1
            border.color: "#cbcbcb"
            radius: 5
            x: 27; z: 1
            y: label.y + label.height + 3
            TextEdit {
                x: 5
                y: 2
                selectByMouse: true
                Keys.onReturnPressed: tweetBox.sendPost();
                Keys.onEnterPressed: tweetBox.sendPost();
                font.pointSize: 15
                id: postInput
                width: parent.width - 10
                height: parent.height - 4
                wrapMode: TextEdit.Wrap;
            }
        }
        Image {
            x: 16
            y: label.y + label.height + 30
            z: 2
            source: "images/tip.png"
        }

        Flow {
            x: postInputContainer.x + postInputContainer.width - width
            id: buttonflow
            y: postInputContainer.y + postInputContainer.height + 5

            NewButton {
                useimg: false

                text: "is.gd"
                onClicked: tweetBox.shortenUrls("is.gd");
                id: isgdButton
            }

            NewButton {
                useimg: false
                text: "Send"
                onClicked: tweetBox.sendPost()
                id: postButton
            }


        }


        Rectangle {
            id: bottomSpacer;
            y: postButton.y + postButton.height
            height: 5
            color: "transparent"
        }
    }
    Rectangle {
        id: dragArea
        width: 60
        height: 50
        //color: "grey"
        gradient: Gradient {
            GradientStop { position: 0.0; color: "#666" }
            GradientStop { position: 1.0; color: "#eee" }
        }
        smooth: true

        border.width: 1
        border.color: "grey"
        radius: 10
        x: inputArea.x + inputArea.width - 5
        y: inputArea.y + 10
        NewButton {
            anchors.centerIn: parent
            id: dragbutton
            z:2
            flat: true
            useimgsize:  true
            bsource: 'images/twitterbird_40x40.png'
            onClicked: {
                if (tweetBox.state != "open") {
                    tweetBox.state = "open"
                    postInput.forceActiveFocus()
                    columnBox.state = "closed"
                    console.log("Opened");
                } else {
                    tweetBox.state = "closed";
                    // mainrow.forceActiveFocus()
                    postInput.focus = false;
                    mainrow.focus = false;
                    console.log("Closed");
                }
            }
            button.drag.axis: Drag.XAxis
            button.drag.target: tweetBox


            onReleased: {
                if (button.drag.active == true) {
                    console.log("dragging tweetBox")
                    console.log("state = " + tweetBox.state)
                    console.log("x = " + tweetBox.x)
                    if (tweetBox.state != "closed") {
                        if (tweetBox.x < 0) {
                            tweetBox.state = "closed"
                            // mainrow.forceActiveFocus()
                        } else {
                            tweetBox.state = "move"
                            columnBox.state = "closed"
                            tweetBox.state = "open"
                            postInput.forceActiveFocus()
                        }
                    } else {
                        if (tweetBox.x > -541) {
                            columnBox.state = "closed"
                            tweetBox.state = "open"
                            postInput.forceActiveFocus()
                        } else {
                            tweetBox.state = "move"
                            tweetBox.state = "closed"
                            // mainrow.forceActiveFocus()
                        }
                    }
                }
            }
        }
    }

    states: [
        State {
            name: "closed"
            PropertyChanges { target: tweetBox; x: screen.width > 480 ? -601 : -381 }
            PropertyChanges { target: inputArea; opacity: 0 }
            PropertyChanges { target: bgimage; x: -140; y: 140 }
            PropertyChanges { target: postInput; focus: false }
        },

        State {
            name: "open"
            PropertyChanges { target: tweetBox; x: screen.width > 480 ? 60 : 50 }
            PropertyChanges { target: inputArea; opacity: 1 }
            PropertyChanges { target: bgimage; x: 0; y: 0 }
            PropertyChanges { target: mainrow; focus: true }
         },
        State {
            name: "move"
            when: dragbutton.button.drag.active == true
            PropertyChanges { target: inputArea; opacity: 1 }
        }
    ]

    function sendPost() {
        console.log ("sendPost clicked with content \"" + postInput.text + "\"");
        tweetBox.state = "closed"
        screen.js().sendTweet(postInput.text, [["in_reply_to_status_id",inReplyTo]]);
        postInput.text = ""
        inReplyTo = "";
        return true
    }

    function shortenUrls(shortener) {
        postInput.text = screen.js().shortenUrl(postInput.text, shortener);
    }
}
